"use strict";
/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSqlServices = exports.SqlModule = exports.SqlSharedModule = void 0;
const langium_1 = require("langium");
const module_1 = require("./generated/module");
const sql_scope_provider_1 = require("./sql-scope-provider");
const sql_validator_1 = require("./sql-validator");
const sql_value_converter_1 = require("./sql-value-converter");
const sql_workspace_manager_1 = require("./sql-workspace-manager");
exports.SqlSharedModule = {
    workspace: {
        WorkspaceManager: (services) => new sql_workspace_manager_1.SqlWorkspaceManager(services)
    }
};
/**
 * Dependency injection module that overrides Langium default services and contributes the
 * declared custom services. The Langium defaults can be partially specified to override only
 * selected services, while the custom services must be fully specified.
 */
exports.SqlModule = {
    parser: {
        ValueConverter: () => new sql_value_converter_1.SqlValueConverter(),
    },
    references: {
        ScopeProvider: (services) => new sql_scope_provider_1.SqlScopeProvider(services),
    },
    validation: {
        ValidationRegistry: (services) => new sql_validator_1.SqlValidationRegistry(services),
        SqlValidator: () => new sql_validator_1.SqlValidator(),
    },
};
/**
 * Create the full set of services required by Langium.
 *
 * First inject the shared services by merging two modules:
 *  - Langium default shared services
 *  - Services generated by langium-cli
 *
 * Then inject the language-specific services by merging three modules:
 *  - Langium default language-specific services
 *  - Services generated by langium-cli
 *  - Services specified in this file
 *
 * @param context Optional module context with the LSP connection
 * @returns An object wrapping the shared services and the language-specific services
 */
function createSqlServices(context) {
    const shared = (0, langium_1.inject)((0, langium_1.createDefaultSharedModule)(context), module_1.SqlGeneratedSharedModule, exports.SqlSharedModule, context.sharedModule);
    const Sql = (0, langium_1.inject)((0, langium_1.createDefaultModule)({ shared }), module_1.SqlGeneratedModule, exports.SqlModule, context.module);
    shared.ServiceRegistry.register(Sql);
    return { shared, Sql };
}
exports.createSqlServices = createSqlServices;
//# sourceMappingURL=sql-module.js.map